[git commit] libbb/sha1: use SSE2 in unrolled x86-64 code. ~10% faster

Denys Vlasenko vda.linux at googlemail.com
Sun Jan 23 11:57:27 UTC 2022


commit: https://git.busybox.net/busybox/commit/?id=39369ff460f3e2dbfec7f6be181b2fb98f3c1867
branch: https://git.busybox.net/busybox/commit/?id=refs/heads/master

function                                             old     new   delta
.rodata                                           108241  108305     +64
sha1_process_block64                                3502    3495      -7
------------------------------------------------------------------------------
(add/remove: 5/0 grow/shrink: 1/1 up/down: 64/-7)              Total: 57 bytes

Signed-off-by: Denys Vlasenko <vda.linux at googlemail.com>
---
 libbb/hash_md5_sha_x86-64.S    | 992 +++++++++++++++++++++++------------------
 libbb/hash_md5_sha_x86-64.S.sh | 440 ++++++++++++------
 2 files changed, 854 insertions(+), 578 deletions(-)

Patch is too large, so refusing to show it


More information about the busybox-cvs mailing list